/*************************************************
* X.509 Certificate Store Header File            *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#ifndef BOTAN_X509_CERT_STORE_H__
#define BOTAN_X509_CERT_STORE_H__

#include <botan/x509cert.h>

namespace Botan {

/*************************************************
* X.509 Certificate Store                        *
*************************************************/
class X509_Store
   {
   public:
      X509_Code validate_cert(const X509_Certificate&);

      std::vector<X509_Certificate> find(const std::string&,
                                         const std::string&) const;

      std::string PEM_encode() const;

      void add_cert(const X509_Certificate&, bool = false);
      void add_certs(DataSource&, X509_Encoding = PEM);
      void add_trusted_certs(DataSource&, X509_Encoding = PEM);
   private:
      struct Cert_Info
         {
         public:
            bool is_verified() const;
            bool is_trusted() const;
            X509_Code verify_result() const;
            void set_result(X509_Code) const;
            Cert_Info(const X509_Certificate&, bool = false);

            X509_Certificate cert;
            bool trusted;
         private:
            mutable bool checked;
            mutable X509_Code result;
            mutable u64bit last_checked;
         };

      void do_add_certs(DataSource&, X509_Encoding, bool);
      u32bit find_parent_of(const X509_Certificate&) const;
      u32bit find_cert(const X509_Certificate&) const;
      X509_Code check_sig(const X509_Certificate&, const Cert_Info&) const;
      X509_Code check_sig(const Cert_Info&, const Cert_Info&) const;
      X509_Code construct_cert_chain(const X509_Certificate&,
                                     std::vector<u32bit>&) const;

      static const u32bit NO_CERT_FOUND = 0xFFFFFFFF;
      std::vector<Cert_Info> certs;
   };

}

#endif
