/*************************************************
* Configuration Handling Source File             *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#include <botan/conf.h>
#include <botan/util.h>
#include <map>

namespace Botan {

namespace Config {

namespace {

std::map<std::string, std::string> options;

}

/*************************************************
* Set an option                                  *
*************************************************/
void add(const std::string& name, const std::string& value)
   {
   options[name] = value;
   }

/*************************************************
* Get the value of an option as a string         *
*************************************************/
std::string get_string(const std::string& name)
   {
   std::map<std::string, std::string>::const_iterator i = options.find(name);
   if(i == options.end())
      return "";
   return i->second;
   }

/*************************************************
* Get the value of an option as a u32bit         *
*************************************************/
u32bit get_u32bit(const std::string& name)
   {
   return to_u32bit(get_string(name));
   }

/*************************************************
* Get the value of an option as a time           *
*************************************************/
u32bit get_time(const std::string& name)
   {
   const std::string timespec = get_string(name);
   if(timespec == "")
      return 0;

   const char suffix = timespec[timespec.size()-1];
   std::string value = timespec.substr(0, timespec.size()-1);

   u32bit scale = 1;

   if(is_digit(suffix))
      value += suffix;
   else if(suffix == 's')
      scale = 1;
   else if(suffix == 'm')
      scale = 60;
   else if(suffix == 'h')
      scale = 60 * 60;
   else if(suffix == 'd')
      scale = 24 * 60 * 60;
   else if(suffix == 'y')
      scale = 365 * 24 * 60 * 60;
   else
      throw Decoding_Error("Config::get_time: Unknown time value " + value);

#if 0
   printf("%s -> %s %c -> %d \n", timespec.c_str(), value.c_str(), suffix,
          (scale*to_u32bit(value)));
#endif

   return scale * to_u32bit(value);
   }

/*************************************************
* Get the value of an option as a bool           *
*************************************************/
bool get_bool(const std::string& name)
   {
   const std::string value = get_string(name);
   if(value == "0" || value == "false")
      return false;
   if(value == "1" || value == "true")
      return true;
   throw Decoding_Error("Config::get_bool: Unknown boolean value " + value);
   }

}

}
